# Generated by roxygen2: do not edit by hand

export(create_stations)
export(plot_station_timeseries)
export(safe_name)
export(simulate_climate_series)
export(validate_climate)
export(validate_climate_internal)
export(write_station_csv)
export(write_station_netcdf)
importFrom(dplyr,`%>%`)
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_x_date)
importFrom(ggplot2,theme_dark)
importFrom(ggplot2,theme_minimal)
importFrom(lubridate,days_in_month)
importFrom(lubridate,month)
importFrom(ncdf4,nc_close)
importFrom(ncdf4,nc_create)
importFrom(ncdf4,ncatt_put)
importFrom(ncdf4,ncdim_def)
importFrom(ncdf4,ncvar_def)
importFrom(ncdf4,ncvar_put)
importFrom(readr,read_csv)
importFrom(rlang,sym)
importFrom(stats,acf)
importFrom(stats,arima.sim)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,ks.test)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,rbinom)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(stats,wilcox.test)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_wider)
importFrom(truncnorm,rtruncnorm)
importFrom(vroom,vroom_write)
