#' CDSim: Climate Data Simulation Toolkit
#'
#' Tools for generating and exporting synthetic climate observation datasets.
#'
#' @docType package
#' @author Isaac Osei and Acheampong Baafi-Adomako and Sivaparvathi Dusari
#' @keywords climate rainfall temperature simulation netcdf
"_PACKAGE"
