% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validation.R
\name{validate_climate}
\alias{validate_climate}
\title{Validate simulated climate data against observations}
\usage{
validate_climate(sim, obs)
}
\arguments{
\item{sim}{Simulated climate data.frame}

\item{obs}{Observed climate data.frame}
}
\value{
A list containing validation metrics and test results
}
\description{
Performs statistical and physical validation of simulated climate data
against observed datasets, including distributional tests, mean comparison,
dependence structure, and temporal persistence.
}
